<template>
  <div class="page">
    <van-nav-bar :left-arrow="routeName !== 'myStationList'" @click-left="onClickLeft">
      <template #title>
        <div class="title">{{ title }}</div>
      </template>
      <template #right>
        <!-- * 跨驻勤点按钮显示条件
             * 1. 当前为【我的辖区】页面
             * 2. 按钮类型rightType=crossStation
             * 3. 跨驻勤点功能为未激活状态 crossStation=false -->
        <van-button v-if="crossStationVisible" type="info" size="small" @click="showCrossStation">跨执勤点</van-button>
      </template>
    </van-nav-bar>
    <keep-alive>
      <router-view v-if="keepAlive"></router-view>
    </keep-alive>
    <router-view v-if="!keepAlive"></router-view>
  </div>
</template>

<script>
import { NavBar, Search, List, Cell, Image as VanImage, Button } from "vant";
import { mapGetters } from "vuex";
export default {
  name: "Layout",
  components: {
    [NavBar.name]: NavBar,
    [Search.name]: Search,
    [List.name]: List,
    [Cell.name]: Cell,
    [VanImage.name]: VanImage,
    [Button.name]: Button,
  },
  computed: {
    ...mapGetters(["rightType", "crossStation", "stationListLength", "sysUserInfo"]),
    stationListLengthCount() {
      // return this.stationListLength.security || this.stationListLength.population || this.stationListLength.temporarySecurity;
      let count = 0;
      for (let key in this.stationListLength) {
        const value = this.stationListLength[key];
        if (value) count += value;
      }
      console.log(count);
      return count > 0;
    },
    crossStationVisible() {
      return this.$route.path === "/myStationList" && this.rightType === "crossStation" && !this.crossStation;
    },
    routeName() {
      return this.$route.name;
    },
    title() {
      const { title } = this.$route.meta;
      if (this.routeName === "myStationList") {
        if (this.sysUserInfo.role === "Proprietor" || this.sysUserInfo.role === "Company") {
          return "我管理的";
        } else {
          return "我的辖区";
        }
      } else if (this.routeName === "stationInfo") {
        return "执勤点详情";
      } else {
        return title;
      }
    },
    keepAlive() {
      const { keepAlive } = this.$route.meta;
      return keepAlive;
    },
  },
  methods: {
    onClickLeft() {
      this.$router.back();
    },
    /**
     * *激活跨驻勤点功能
     * !如果列表长度小于等于0，不触发
     */
    showCrossStation() {
      console.log(this.stationListLengthCount);
      if (this.stationListLengthCount > 0) this.$store.commit("TOGGLE_CROSS_STATION");
    },
  },
};
</script>

<style scoped lang="less">
.page {
  .title {
    font-family: PingFang SC-Regular, PingFang SC, serif;
  }
}
</style>
